==> slap-react-native-toggle-1.0.4.tgz: package/components/Header.js <==
import React, { Component } from 'react';
import { Text, View, TouchableWithoutFeedback } from 'react-native';
import PropTypes from 'prop-types';
import { Ionicons, SimpleLineIcons } from '@expo/vector-icons';

export default class Header extends Component {
  static propTypes = {
    title: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.element,
      PropTypes.array
    ]),
    titleColor: PropTypes.string,
    titleFontSize: PropTypes.number,
    onPressTitle: PropTypes.func,
    backgroundColor: PropTypes.string,
    leftIcon: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.element
    ]),
    leftIconColor: PropTypes.string,
    leftIconSize: PropTypes.number,
    onPressLeftIcon: PropTypes.func,
    rightIcon: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.element
    ]),
    rightIconColor: PropTypes.string,
    rightIconSize: PropTypes.number,
    onPressRightIcon: PropTypes.func,
    height: PropTypes.number.isRequired
  };

  static defaultProps = {
    title: '',
    titleColor: '#1d1d1d',
    titleFontSize: 18,
    onPressTitle: () => {},
    backgroundColor: '#ffffff',
    leftIcon: 'default',
    leftIconColor: '#1d1d1d',
    leftIconSize: 52,
    onPressLeftIcon: () => {},
    rightIcon: 'default',
    rightIconColor: '#1d1d1d',
    rightIconSize: 26,
    onPressRightIcon: () => {},
    height: 60
  };

  isExecuted = false;
  
  onPressTitle = () => {
    if (this.isExecuted) {
      return;
    }

    this.isExecuted = true;

    setTimeout(() => {
      this.isExecuted = false;
    }, 1000);

    this.props.onPressTitle();
  };

  onPressLeftIcon = () => {
    if (this.isExecuted) {
      return;
    }

    this.isExecuted = true;

    setTimeout(() => {
      this.isExecuted = false;
    }, 1000);

    this.props.onPressLeftIcon();
  };

  onPressRightIcon = () => {
    if (this.isExecuted) {
      return;
    }

    this.isExecuted = true;

    setTimeout(() => {
      this.isExecuted = false;
    }, 1000);

    this.props.onPressRightIcon();
  };

  render() {
    let leftIcon = null;
    
    if (this.props.leftIcon == 'default') {
      leftIcon = <Ionicons name="ios-arrow-round-back" color={this.props.leftIconColor} size={this.props.leftIconSize} />;
    }
    else {
      leftIcon = this.props.leftIcon;
    }

    let rightIcon = null;

    if (this.props.rightIcon == 'default') {
      rightIcon = <SimpleLineIcons name="bell" color={this.props.rightIconColor} size={this.props.rightIconSize} />;
    }
    else {
      rightIcon = this.props.rightIcon;
    }

    return (
      <View style={{ flexDirection: 'row', backgroundColor: this.props.backgroundColor, height: this.props.height }}>
        <View style={{ flex: 1 }}>
          { leftIcon &&
            <TouchableWithoutFeedback onPress={this.onPressLeftIcon}>
              <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
                { leftIcon }
              </View>
            </TouchableWithoutFeedback>
          }
        </View>
        { typeof this.props.title == 'string' &&
          <View style={{ flex: 4 }}>
            <TouchableWithoutFeedback onPress={this.onPressTitle}>
              <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
                <Text style={{ color: this.props.titleColor, fontSize: this.props.titleFontSize }}>{ this.props.title }</Text>
              </View>
            </TouchableWithoutFeedback>
          </View>
        }
        { typeof this.props.title != 'string' &&
          <View style={{ flex: 4 }}>
            <TouchableWithoutFeedback onPress={this.onPressTitle}>
              <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
                { this.props.title }
              </View>
            </TouchableWithoutFeedback>
          </View>
        }
        <View style={{ flex: 1 }}>
          { rightIcon &&
            <TouchableWithoutFeedback onPress={this.onPressRightIcon}>
              <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
                { rightIcon }
              </View>
            </TouchableWithoutFeedback>
          }
        </View>
      </View>
    );
  }
}

==> slap-react-native-toggle-3.0.3.tgz: package/components/Header.js <==
import React, { Component } from 'react';
import { Text, View, TouchableWithoutFeedback } from 'react-native';
import PropTypes from 'prop-types';
import Ionicons from 'react-native-vector-icons/Ionicons';

export default class Header extends Component {
  static propTypes = {
    title: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.element,
      PropTypes.array
    ]),
    titleColor: PropTypes.string,
    titleFontSize: PropTypes.number,
    onPressTitle: PropTypes.func,
    backgroundColor: PropTypes.string,
    leftIcon: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.element
    ]),
    onPressLeftIcon: PropTypes.func,
    rightIcon: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.element
    ]),
    onPressRightIcon: PropTypes.func,
    height: PropTypes.number,
    debounce: PropTypes.number
  };

  static defaultProps = {
    title: '',
    titleColor: '#4d4d4d',
    titleFontSize: 18,
    onPressTitle: () => {},
    backgroundColor: '#ffffff',
    leftIcon: <Ionicons name="ios-arrow-round-back" color="#4d4d4d" size={52} />,
    onPressLeftIcon: () => {},
    rightIcon: <View />,
    onPressRightIcon: () => {},
    height: 60,
    debounce: 1000
  };

  isPressed = false;

  onPressTitle = () => {
    if (this.isPressed) {
      return;
    }

    this.isPressed = true;

    setTimeout(() => {
      this.isPressed = false;
    }, this.props.debounce);

    this.props.onPressTitle();
  };

  onPressLeftIcon = () => {
    if (this.isPressed) {
      return;
    }

    this.isPressed = true;

    setTimeout(() => {
      this.isPressed = false;
    }, this.props.debounce);

    this.props.onPressLeftIcon();
  };

  onPressRightIcon = () => {
    if (this.isPressed) {
      return;
    }

    this.isPressed = true;

    setTimeout(() => {
      this.isPressed = false;
    }, this.props.debounce);

    this.props.onPressRightIcon();
  };

  render() {
    return (
      <View style={{ flexDirection: 'row', backgroundColor: this.props.backgroundColor, height: this.props.height }}>
        <View style={{ flex: 1 }}>
          { this.props.leftIcon &&
            <TouchableWithoutFeedback onPress={this.onPressLeftIcon}>
              <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
                { this.props.leftIcon }
              </View>
            </TouchableWithoutFeedback>
          }
        </View>
        { typeof this.props.title == 'string' &&
          <View style={{ flex: 4 }}>
            <TouchableWithoutFeedback onPress={this.onPressTitle}>
              <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
                <Text style={{ color: this.props.titleColor, fontSize: this.props.titleFontSize }}>{ this.props.title }</Text>
              </View>
            </TouchableWithoutFeedback>
          </View>
        }
        { typeof this.props.title != 'string' &&
          <View style={{ flex: 4 }}>
            <TouchableWithoutFeedback onPress={this.onPressTitle}>
              <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
                { this.props.title }
              </View>
            </TouchableWithoutFeedback>
          </View>
        }
        <View style={{ flex: 1 }}>
          { this.props.rightIcon &&
            <TouchableWithoutFeedback onPress={this.onPressRightIcon}>
              <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
                { this.props.rightIcon }
              </View>
            </TouchableWithoutFeedback>
          }
        </View>
      </View>
    );
  }
}
